.. _tutorial:

Tutorial
========

The Charmcraft tutorials are the best entry point for anyone new to making charms. They
teach the basics of charming from functional, reproducible examples.


12-factor app extensions
------------------------

Charmcraft's extensions enable you to build Django, FastAPI, Flask, and Go applications
with just a few modifications to the YAML template content. To familiarize yourself
with one of these workflows, start with its tutorial:

* :ref:`write-your-first-kubernetes-charm-for-a-django-app`
* :ref:`write-your-first-kubernetes-charm-for-a-expressjs-app`
* :ref:`write-your-first-kubernetes-charm-for-a-fastapi-app`
* :ref:`write-your-first-kubernetes-charm-for-a-flask-app`
* :ref:`write-your-first-kubernetes-charm-for-a-go-app`
* :ref:`write-your-first-kubernetes-charm-for-a-spring-boot-app`


.. toctree::
    :hidden:

    kubernetes-charm-django
    kubernetes-charm-express
    kubernetes-charm-fastapi
    kubernetes-charm-flask
    kubernetes-charm-go
    kubernetes-charm-spring-boot
